@@ -1,34 +1,35 @@
 def getimagesize(url):
     """
-    Attempts to determine an image's width and height, and returns a string
-    suitable for use in an <img> tag, or an empty string in case of failure.
+    Attempts to determine an image's width and height, and returns a tuple,
+    (width, height), in pixels or an empty string in case of failure.
     Requires that PIL is installed.
 
     >>> getimagesize("http://www.google.com/intl/en_ALL/images/logo.gif")
-    ... #doctest: +ELLIPSIS
-    'width="..." height="..."'
-
+    (276, 110)
     >>> getimagesize("http://bad.domain/")
     ''
-
     """
 
     try:
-        import ImageFile
-        import urllib2
+        from PIL import ImageFile
     except ImportError:
         return ''
 
+    try:
+        from urllib.request import urlopen
+    except (ImportError):
+        from urllib2 import urlopen
+
     try:
         p = ImageFile.Parser()
-        f = urllib2.urlopen(url)
+        f = urlopen(url)
         while True:
             s = f.read(1024)
             if not s:
                 break
             p.feed(s)
             if p.image:
-                return 'width="%i" height="%i"' % p.image.size
+                return p.image.size
     except (IOError, ValueError):
         return ''
 
@@ -36,6 +37,6 @@ def getimagesize(url):
 def setup_module(module):
     from nose.plugins.skip import SkipTest
     try:
-        import ImageFile
+        __import__('PIL')
     except ImportError:
         raise SkipTest()
